@@ -606,16 +606,26 @@ class MainWindow(hildon.StackableWindow):
 
     def read_config(self):
         config = ConfigParser.SafeConfigParser()
-        config.read('./fSchedule.default')
-        self.defaultsite = int(config.get('default', 'defaultsite'))
+        try:
+            config.read('fSchedule.default')        
+            self.defaultsite = int(config.get('default', 'defaultsite'))
+        except Exception:
+            self.defaultsite = 0
 
     def write_config(self):
-        config = ConfigParser.SafeConfigParser()
-        config.read('fSchedule.default')
-        config.set('default', 'defaultsite', str(self.defaultsite))
-        # Writing our configuration file to 'example.cfg'
-        config.write(open('./fSchedule.default', 'w'))
-
+        try:
+            config = ConfigParser.SafeConfigParser()
+            config.read('fSchedule.default')
+            config.set('default', 'defaultsite', str(self.defaultsite))
+            # Writing our configuration file to 'example.cfg'
+            config.write(open('fSchedule.default', 'w'))
+        except Exception:
+            #If there is no config file
+            config_raw = ConfigParser.RawConfigParser()
+            config_raw.add_section('default')
+            config_raw.set('default', 'defaultsite', str(self.defaultsite))
+            #Writing our new configuration to file 'fSchedule.default'
+            config_raw.write(open('fSchedule.default', 'wb'))        
         
 class fSchedule(hildon.Program):
 	def __init__(self):
